from setuptools import setup, find_packages

setup(name='links_pydriver',
      version='0.2',
      description='A python driver for Links',
      url='https://github.com/tanguyesteoule/links_pydriver',
      author='Tanguy Esteoule',
      author_email='tanguy.esteoule@gmail.com',
      license='MIT',
      packages = find_packages(),
      zip_safe=False)